SignInWithVerificationCode class

Constructors

SignInWithVerificationCode({FirebaseAuth? firebaseAuth})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resendVerificationCode({required String provider, required String method, required String phoneNumber, required int resendToken, required VerificationSuccessCallback onSuccess, required VerificationErrorCallback onError}) Future<void>
Resends a phone verification code using resendToken.
sendVerificationCode({required String provider, required String method, required String phoneNumber, required VerificationSuccessCallback onSuccess, required VerificationErrorCallback onError}) Future<void>
Sends a phone verification code to the specified phoneNumber.
toString() String
A string representation of this object.
inherited
validateVerificationCode({required String provider, required String method, required String smsCode, required String verificationId}) Future<Map<String, dynamic>?>
Verifies the phone code with the provided smsCode and verificationId.

Operators

operator ==(Object other) bool
The equality operator.
inherited