SignInUtils class

Constructors

SignInUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

areFirebaseOptionsEqual(FirebaseOptions a, FirebaseOptions b) bool
fromGoogleUser(GoogleSignInAccount account, {SignInProvider? provider}) → AuthenticatedUser
convert a Google user account to our User
getAppIdFromYaml() Future<String?>