TokenManagerImpl class
Constructors
- TokenManagerImpl()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getServiceTokens(
OAuthService serviceName) → Future< OAuthServiceToken?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateServiceTokens(
OAuthService serviceName, String accessToken, {String? refreshToken}) → Future< void> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited