AuthContextManagerImpl class
publicly exposed as Context
- Mixed-in types
-
- Invokable
Constructors
Properties
- definition ↔ SourceSpan?
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getList(
Object obj) → List? -
inherited
-
getMap(
Object obj) → Map? -
inherited
-
getMethod(
dynamic method) → Function? -
inherited
-
getProperty(
dynamic prop) → dynamic -
inherited
-
getSignedInUser(
) → Future< AuthenticatedUser?> -
this method is exposed to the main module
override
-
getString(
Object obj) → String? -
inherited
-
getters(
) → Map< String, Function> -
mark these functions as protected as we need the implementations,
but discourage direct usages.
Reasons:
override
-
hasGettableProperty(
dynamic prop) → bool -
inherited
-
hasMethod(
dynamic method) → bool -
inherited
-
hasSettableProperty(
dynamic prop) → bool -
inherited
-
methods(
) → Map< String, Function> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resendVerificationCode(
{required String provider, required String method, required String phoneNumber, required int resendToken, required dynamic onSuccess(String verificationId, int? resendToken), required dynamic onError(String error)}) → Future< void> -
Resends the verification code using
resendToken.override -
sendVerificationCode(
{required String provider, required String method, required String phoneNumber, required dynamic onSuccess(String verificationId, int? resendToken), required dynamic onError(String error)}) → Future< void> -
Sends a phone verification code to the given phone number.
override
-
setProperty(
dynamic prop, dynamic val) → void -
update a property. If this is a HasController (i.e. Widget), notify it of changes
inherited
-
setters(
) → Map< String, Function> -
override
-
signOut(
) → Future< void> -
this method is exposed to the main module
override
-
toString(
) → String -
A string representation of this object.
inherited
-
validateVerificationCode(
{required String provider, required String method, required String smsCode, required String verificationId, required dynamic onSuccess(AuthenticatedUser, String idToken), required dynamic onError(String error), required dynamic onVerificationFailure(String error)}) → Future< AuthenticatedUser?> -
Verifies a phone code using
smsCodeandverificationId.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited