AuthManager class

This abstract out different method of Sign In (local, custom, Firebase, Auth0, ...)

Mixed-in types

Constructors

AuthManager()
factory

Properties

customFirebaseApp ↔ FirebaseApp?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCurrentUser() → AuthenticatedUser?
inherited
getSignedInUser() Future<AuthenticatedUser?>
hasCurrentUser() bool
inherited
isSignedIn() Future<bool>
check if the user is current signed in or not.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signInAnonymously(BuildContext context) Future<String?>
signInWithCustomToken(BuildContext context, {required String jwtToken}) Future<String?>
signInWithServerCredential(BuildContext context, {required AuthenticatedUser user, required String idToken, required SignInWithServerAPIAction signInAPI}) Future<String?>
After authenticated the user, redirect to a Server API with the idToken to retrieve Server-specific credentials (bearer, cookies,..). Once completed we sign the user in, and save the credentials to ${auth.user.data}
signInWithSocialCredential(BuildContext context, {required AuthenticatedUser user, required String idToken, AuthToken? token, String? authCode, String? rawNonce}) Future<String?>
Sign in with credentials from providers (e.g. Google, Apple) or via Firebase
signOut(BuildContext context) Future<void>
toString() String
A string representation of this object.
inherited
updateCurrentFirebaseUser(BuildContext context, User newUser) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited