GoogleAuthManager class
Managing Google Sign in
Constructors
- GoogleAuthManager()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
canAccessScopes(
List< String> scopes) → Future<bool> ? -
getSignedInUser(
) → Future< GoogleSignInAccount?> - return the account currently signed in
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerSignInListener(
{List< String> ? scopes, required GoogleSignInAccountCallback onAccountChanged}) → Future<void> -
signIn(
) → Future< GoogleSignInAccount?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited